@@ -17,10 +17,12 @@
 
 use strict;
 use warnings;
+
+package Password::Policy::Exception::Pwned;
  
 use parent 'Password::Policy::Exception';
 
-our $VERSION = '0.00';
+our $VERSION = '0.00_01';
 
 sub error { return 'This password has been pwned'; }
 
